@@ -25,7 +25,7 @@
 
 #include <Lum/Config/Config.h>
 
-#include <Lum/Model/Integer.h>
+#include <Lum/Model/Number.h>
 
 class Alternative
 {
