@@ -45,21 +45,11 @@ private:
   Lum::Model::StringRef hexFormat;
   bool                  formatConversion;
 
-  Lum::Model::ActionRef binFocusIn;
-  Lum::Model::ActionRef octFocusIn;
-  Lum::Model::ActionRef decFocusIn;
-  Lum::Model::ActionRef hexFocusIn;
-  Lum::Model::ActionRef focusOut;
-
-  Lum::Model::ActionRef digitsPressed[17];
-
   Lum::String          *bin;
   Lum::String          *oct;
   Lum::String          *dec;
   Lum::String          *hex;
 
-  InputTarget           inputTarget;
-
 private:
   void ConvertFromBin();
   void ConvertFromOct();
@@ -68,7 +58,6 @@ private:
 
 public:
   FormatConversion();
-  ~FormatConversion();
 
   void CalcSize();
 
