@@ -23,7 +23,7 @@
 
 #include <Lum/Def/OneOfMany.h>
 
-#include <Lum/OS/Behaviour.h>
+#include <Lum/Manager/Behaviour.h>
 
 #include <Lum/Combo.h>
 #include <Lum/Label.h>
@@ -65,22 +65,22 @@ void UnitConversion::CalcSize()
 
   label=new Lum::Label();
 
-  oneOfMany=Lum::OS::display->GetBehaviour()->GetOneOfManyControl(typeDef);
+  oneOfMany=Lum::Manager::Behaviour::Instance()->GetOneOfManyControl(typeDef);
   oneOfMany->SetFlex(true,false);
   label->AddLabel(L"Type:",oneOfMany);
 
-  oneOfMany=Lum::OS::display->GetBehaviour()->GetOneOfManyControl(srcDef);
+  oneOfMany=Lum::Manager::Behaviour::Instance()->GetOneOfManyControl(srcDef);
   oneOfMany->SetFlex(true,false);
   label->AddLabel(L"Source Unit:",oneOfMany);
 
-  oneOfMany=Lum::OS::display->GetBehaviour()->GetOneOfManyControl(destDef);
+  oneOfMany=Lum::Manager::Behaviour::Instance()->GetOneOfManyControl(destDef);
   oneOfMany->SetFlex(true,false);
   label->AddLabel(L"Destination Unit:",oneOfMany);
 
   string=new Lum::String();
   string->SetFlex(true,false);
   string->SetAlignment(Lum::String::right);
-  string->SetInputHelper(new Lum::InputHelperNumber(Lum::InputHelperNumber::typeFloat));
+  string->SetInputTypeHint(Lum::Object::inputTypeSignedFloatNumber);
   string->SetModel(value);
   label->AddLabel(L"Value:",string);
 
